@@ -1,9 +1,10 @@
 """
-Module for driving large reduction processes.
+Module for driving reduction processes. Contains highest-level API.
 """
 
 from glob import glob
 
+import numpy as np
 import pandas as pd
 from tqdm import tqdm
 
@@ -13,7 +14,9 @@ from . import search_headers as search
 from . import sky
 
 
-def all_driver(inst, config_file, raw_dir, reddir, plotting_yml=None):
+def all_driver(
+    inst, config_file, raw_dir, reddir, plotting_yml=None, searchsize=10
+):
     """
     Runs all drivers, performing an end-to-end reduction.
 
@@ -21,9 +24,9 @@ def all_driver(inst, config_file, raw_dir, reddir, plotting_yml=None):
         :inst: (Instrument object) instrument for which data is being reduced.
         :config_file: (string) path of the config file containing plotting
             specifications. Optional.
-        :plotting_yml: (string) path to the y
         :raw_dir: (string) path of the directory containing the raw data.
         :reddir: (string) path of the directory to contain the raw data.
+        :plotting_yml: (string) path to the plotting configuration file.
 
     """
 
@@ -43,12 +46,25 @@ def all_driver(inst, config_file, raw_dir, reddir, plotting_yml=None):
     methods = image.image_driver(raw_dir, reddir, config, inst)
 
     star_dirlist = glob(reddir + "*/")
-    i = 0  # can't use tqdm on zipped objects, I believe
-    for s_dir in tqdm(
-        star_dirlist, desc="Running registration", position=0, leave=True
+
+    # we want to ensure that the code doesn't attempt to reduce folders
+    # that are in the reduced directory but not in the config
+
+    cleaned_star_dirlist = [
+        star_dir
+        for star_dir in star_dirlist
+        for ob in config.Object
+        if ob in star_dir
+    ]
+    for i, s_dir in enumerate(
+        tqdm(
+            np.unique(cleaned_star_dirlist),
+            desc="Running registration",
+            position=0,
+            leave=True,
+        )
     ):
-        image.create_im(s_dir, 10, method=methods[i])
-        i += 1
+        image.create_im(s_dir, searchsize, method=methods[i])
 
 
 def config_driver(inst, config_file, raw_dir, reddir):
