@@ -99,7 +99,7 @@ def image_driver(raw_dir, reddir, config, inst, plotting_yml=None):
             if np.all(pd.isnull(obj_methods)):
                 methods.append("default")
             else:
-                obj_method = obj_methods[~pd.isnull(obj_methods)][0]
+                obj_method = obj_methods[~pd.isnull(obj_methods)][0].lower()
                 if "saturated" and "wide" in obj_method:
                     methods.append("saturated wide")
                 elif "saturated" in obj_method and "wide" not in obj_method:
@@ -222,7 +222,7 @@ def create_im(s_dir, ssize1, plotting_yml=None, fdirs=None, method="default"):
     for sf_dir in fdirs:  # each filter
 
         files = glob(
-            sf_dir + f"s*.fits"
+            sf_dir + f"sh*.fits"
         )  # might need to change to file_prefix
         nims = len(files)
         frames = u.read_imcube(files)
